resource "openstack_compute_instance_v2" "management_instance" {
    for_each = var.hosts
    name = "${each.key}.${var.competition_domain}"
    depends_on = [ openstack_networking_subnet_v2.management_subnet, openstack_networking_subnet_v2.alternate_subnet ]
    flavor_id = each.value.flavor
    security_groups = [
        "default",
        local.secgroups[each.value.secgroup],
    ]
    block_device {
        uuid = each.value.image
        boot_index = 0
        volume_size = each.value.size
        delete_on_termination = true
        source_type = "image"
        destination_type = "volume"
    }
    network {
        // assign a uuid
        uuid = local.networks[each.value.network]
        // assign the ip
        fixed_ip_v4 = each.value.ip
    }
    user_data = lookup(each.value, "user_data", null)
}

resource "openstack_compute_instance_v2" "vpn_instance" {
    name = var.vpn.hostname
    flavor_id = var.vpn.flavor
    security_groups = [
        "default",
        local.secgroups[var.vpn.internal_secgroup],
        local.secgroups[var.vpn.external_secgroup],
    ]
    block_device {
        uuid = var.vpn.image
        boot_index = 0
        volume_size = var.vpn.size
        delete_on_termination = true
        source_type = "image"
        destination_type = "volume"
    }
    network {
        port = openstack_networking_port_v2.vpn_public_ip_port.id
    }
    network {
        port = openstack_networking_port_v2.vpn_vpn_network_port.id
    }
    user_data = var.vpn.user_data
    config_drive = true     # THIS IS REQUIRED FOR THERE TO BE 2 INTERFACES
}
