// Switching Plane
resource "openstack_networking_network_v2" "switching_plane" {
    name = "${var.competition_name} Switching Plane"
}

resource "openstack_networking_subnet_v2" "switching_plane_subnet" {
    name = "${var.competition_name} Switching Plane Subnet"
    network_id = openstack_networking_network_v2.switching_plane.id
    cidr = "10.100.0.0/24"
    gateway_ip = "10.100.0.254"
    ip_version = 4
    allocation_pool {
        start = "10.100.0.200"
        end = "10.100.0.253"
    }
    dns_nameservers =  [
        "172.16.0.1",
        "172.16.0.2"
    ]
}

resource "openstack_networking_port_v2" "switching_plane_router_port" {
    name = "Switching Plane Port"
    network_id = openstack_networking_network_v2.switching_plane.id
    fixed_ip {
        subnet_id = openstack_networking_subnet_v2.switching_plane_subnet.id
        ip_address = "10.100.0.254"
    }
}

resource "openstack_networking_router_interface_v2" "switching_plane_interface" {
    router_id = var.core_router
    port_id = openstack_networking_port_v2.switching_plane_router_port.id
}

// Management Network
resource "openstack_networking_network_v2" "management_network" {
    name = "${var.competition_name} Management Network"
}

resource "openstack_networking_subnet_v2" "management_subnet" {
    name = "${var.competition_name} Management Subnet"
    network_id = openstack_networking_network_v2.management_network.id
    cidr = "172.16.0.0/24"
    gateway_ip = "172.16.0.254"
    ip_version = 4
    allocation_pool {
        start = "172.16.0.200"
        end = "172.16.0.253"
    }
    dns_nameservers = [
        "1.1.1.1",
        "1.0.0.1",
    ]
}

resource "openstack_networking_port_v2" "management_router_port" {
    name = "Management Router Port"
    network_id = openstack_networking_network_v2.management_network.id
    fixed_ip {
        subnet_id = openstack_networking_subnet_v2.management_subnet.id
        ip_address = "172.16.0.254"
    }
}

resource "openstack_networking_router_interface_v2" "management_interface" {
    router_id = var.core_router
    port_id = openstack_networking_port_v2.management_router_port.id
}

// Alternate Network
resource "openstack_networking_network_v2" "alternate_network" {
    name = "${var.competition_name} Alternate Network"
}

resource "openstack_networking_subnet_v2" "alternate_subnet" {
    name = "${var.competition_name} Alternet Subnet"
    network_id = openstack_networking_network_v2.alternate_network.id
    cidr = "172.24.0.0/24"
    gateway_ip = "172.24.0.254"
    allocation_pool {
        start = "172.24.0.200"
        end = "172.24.0.253"
    }
    dns_nameservers = [
        "1.1.1.1",
        "1.0.0.1"
    ]
}

resource "openstack_networking_router_v2" "alternate_router" {
    name = "${var.competition_name} Alternate Router"
    external_network_id = var.external_network
}

resource "openstack_networking_port_v2" "alternate_router_port" {
    name = "Alternate Router Port"
    network_id = openstack_networking_network_v2.alternate_network.id
    fixed_ip {
        subnet_id = openstack_networking_subnet_v2.alternate_subnet.id
        ip_address = "172.24.0.254"
    }
}

resource "openstack_networking_router_interface_v2" "alternate_interface" {
    router_id = openstack_networking_router_v2.alternate_router.id
    port_id = openstack_networking_port_v2.alternate_router_port.id
}

// Phone Network
resource "openstack_networking_network_v2" "phone_network" {
    name = "${var.competition_name} Phone Network"
    segments {
        physical_network = "physnet1"
        network_type = "vlan"
        segmentation_id = "517"
    }
}

resource "openstack_networking_subnet_v2" "phone_subnet" {
    name = "${var.competition_name} Phone Subnet"
    network_id = openstack_networking_network_v2.phone_network.id
    cidr = "172.26.0.0/24"
    gateway_ip = "172.26.0.254"
    allocation_pool {
        start = "172.26.0.200"
        end = "172.26.0.253"
    }
    dns_nameservers = [
        "1.1.1.1",
        "1.0.0.1"
    ]
}

resource "openstack_networking_port_v2" "phone_router_port" {
    name = "Phone Router Port"
    network_id = openstack_networking_network_v2.phone_network.id
    fixed_ip {
        subnet_id = openstack_networking_subnet_v2.phone_subnet.id
        ip_address = "172.26.0.254"
    }
}

resource "openstack_networking_router_interface_v2" "phone_interface" {
    router_id = var.core_router
    port_id = openstack_networking_port_v2.phone_router_port.id
}

// Floating IPs
resource "openstack_networking_floatingip_v2" "public_ip" {
    for_each = toset([ "vpn", "ctf", "ctfd", "deploy", "scoring", "beat", "store" ])
    pool = "RIT_WAN"
}

resource "openstack_compute_floatingip_associate_v2" "public_instance_ip_associate" {
    for_each = toset([ "ctf", "ctfd", "deploy", "scoring", "beat", "store" ])
    depends_on = [
        openstack_compute_instance_v2.management_instance["ctf"],
        openstack_compute_instance_v2.management_instance["ctfd"],
        openstack_compute_instance_v2.management_instance["deploy"],
        openstack_compute_instance_v2.management_instance["scoring"],
        openstack_compute_instance_v2.management_instance["beat"],
        openstack_compute_instance_v2.management_instance["store"]
    ]
    floating_ip = openstack_networking_floatingip_v2.public_ip[each.key].address
    instance_id = openstack_compute_instance_v2.management_instance[each.key].id
}

// VPN Networking
resource "openstack_networking_network_v2" "vpn_network" {
    name = "${var.competition_name} VPN Network"
}

resource "openstack_networking_subnet_v2" "vpn_subnet" {
    name = "${var.competition_name} VPN Subnet"
    network_id = openstack_networking_network_v2.vpn_network.id
    cidr = "172.28.0.0/24"
    no_gateway = true
    ip_version = 4
    allocation_pool {
        start = "172.28.0.200"
        end = "172.28.0.253"
    }
    dns_nameservers = [
        "1.1.1.1",
        "1.0.0.1"
    ]
}

resource "openstack_networking_port_v2" "vpn_network_router_port" {
    name = "VPN Network Router Port"
    network_id = openstack_networking_network_v2.vpn_network.id
    fixed_ip {
        subnet_id = openstack_networking_subnet_v2.vpn_subnet.id
        ip_address = "172.28.0.254"
    }
}

resource "openstack_networking_router_interface_v2" "vpn_network_core_router_interface" {
    router_id = var.core_router
    port_id = openstack_networking_port_v2.vpn_network_router_port.id
}

resource "openstack_networking_port_v2" "vpn_vpn_network_port" {
    name = "VPN VPN Network Port"
    description = "port for vpn host on vpn network"
    network_id = openstack_networking_network_v2.vpn_network.id
    fixed_ip {
        subnet_id = openstack_networking_subnet_v2.vpn_subnet.id
        ip_address = var.vpn.vpn_network_ip
    }
    allowed_address_pairs {
        ip_address = var.vpn.subnet
    }
    security_group_ids = [ local.secgroups[var.vpn.internal_secgroup] ]
}

resource "openstack_networking_port_v2" "vpn_public_ip_port" {
    name = "VPN Public IP Port"
    description = "port to assicate alternate network interface of vpn with floating IP"
    network_id = openstack_networking_network_v2.alternate_network.id
    fixed_ip {
        subnet_id = openstack_networking_subnet_v2.alternate_subnet.id
        ip_address = var.vpn.alternate_ip
    }
    security_group_ids = [ local.secgroups[var.vpn.external_secgroup] ]
}

resource "openstack_networking_floatingip_associate_v2" "vpn_public_ip_associate" {
    depends_on = [
        openstack_networking_floatingip_v2.public_ip["vpn"],
        openstack_networking_port_v2.vpn_public_ip_port
    ]
    floating_ip = openstack_networking_floatingip_v2.public_ip["vpn"].address
    port_id = openstack_networking_port_v2.vpn_public_ip_port.id
}

resource "openstack_networking_router_route_v2" "competition_vpn_route" {
    depends_on = [ openstack_compute_instance_v2.vpn_instance ]
    router_id = var.core_router
    destination_cidr = var.vpn.subnet
    next_hop = var.vpn.vpn_network_ip
}

resource "openstack_networking_router_route_v2" "alternate_vpn_route" {
    depends_on = [ openstack_compute_instance_v2.vpn_instance ]
    router_id = openstack_networking_router_v2.alternate_router.id
    destination_cidr = var.vpn.subnet
    next_hop = var.vpn.alternate_ip
}

resource "openstack_networking_subnet_route_v2" "nexthop_vpn_subnet_route" {
    for_each = toset([ "10.0.0.0/8", "172.16.0.0/12", "192.168.0.0/16" ])
    subnet_id = openstack_networking_subnet_v2.vpn_subnet.id
    destination_cidr = each.key
    next_hop = "172.28.0.254"
}

locals {
    networks = {
       "management": openstack_networking_network_v2.management_network.id
       "alternate": openstack_networking_network_v2.alternate_network.id
       "phone": openstack_networking_network_v2.phone_network.id
    }
}