provider "openstack" {
    tenant_name = var.project_name
    user_name = var.username
    password = var.password
    auth_url = var.auth_url
}

// Management Project
data "openstack_identity_project_v3" "management_project" {
    name = var.project_name
}

// Openstack External Network
data "openstack_networking_network_v2" "external_network" {
    name = "RIT_WAN"
}

// Flavor Data
data "openstack_compute_flavor_v2" "flavor_medium" {
    name = "Medium general"
}

data "openstack_compute_flavor_v2" "flavor_medium_mem"{
    name = "Medium memory"
}

data "openstack_compute_flavor_v2" "flavor_large" {
    name = "Large general"
}

data "openstack_compute_flavor_v2" "flavor_large_mem" {
    name = "Large memory"
}


// Image Data
data "openstack_images_image_v2" "image_win_serv_2019" {
    name = "NEW_ISTS_2022_Windows_Server_2019"
}

data "openstack_images_image_v2" "image_ubuntu_20" {
    name = "ISTS_2022_ubuntu_2004_desktop"
}

data "openstack_images_image_v2" "image_ubuntu_20_cloud" {
    name = "ISTS_2022_ubuntu_2004_cloud"
}

// Build the core router
resource "openstack_networking_router_v2" "core_router" {
    name = "${var.competition_name} Core Router"
    external_network_id = data.openstack_networking_network_v2.external_network.id
}

// Build the Competition Infrastructure
module "comp_mgmt" {
    source ="./comp_mgmt"
    competition_domain = var.competition_domain
    competition_name = var.competition_name
    core_router = openstack_networking_router_v2.core_router.id
    external_network = data.openstack_networking_network_v2.external_network.id
    project_id = data.openstack_identity_project_v3.management_project.id

    vpn = {
        "hostname": "vpn.${var.competition_domain}"
        "image": data.openstack_images_image_v2.image_ubuntu_20_cloud.id
        "flavor": data.openstack_compute_flavor_v2.flavor_medium.id
        "size": 20
        "subnet": "172.16.128.0/17"
        "alternate_ip": "172.24.0.16"
        "vpn_network_ip": "172.28.0.16"
        "external_secgroup": "vpn_external"
        "internal_secgroup": "vpn_internal"
        "user_data": templatefile("../files/cloud-init-management-dynamic-dns.yaml", var.vpn_ddclient_vars)
    }

    hosts = {
        "dns1": {
            "image": data.openstack_images_image_v2.image_win_serv_2019.id
            "flavor": data.openstack_compute_flavor_v2.flavor_medium_mem.id
            "size": 30
            "ip": "172.16.0.1"
            "secgroup": "dns"
            "network": "management"
        }
        "dns2": {
            "image": data.openstack_images_image_v2.image_win_serv_2019.id
            "flavor": data.openstack_compute_flavor_v2.flavor_medium_mem.id
            "size": 30
            "ip": "172.16.0.2"
            "secgroup": "dns"
            "network": "management"
        }
        "choco": {
            "image": data.openstack_images_image_v2.image_win_serv_2019.id
            "flavor": data.openstack_compute_flavor_v2.flavor_medium.id
            "size": 20
            "ip": "172.16.0.3"
            "secgroup": "game"
            "network": "management"
        }
        "deploy": {
             "image": data.openstack_images_image_v2.image_ubuntu_20_cloud.id
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 20
            "ip": "172.16.0.4"
            "secgroup": "deploy"
            "network": "management"
            "user_data": templatefile("../files/cloud-init-management-dynamic-dns.yaml", var.deploy_ddclient_vars)
        }
        "game": {
            "image": data.openstack_images_image_v2.image_ubuntu_20_cloud.id
            "flavor": data.openstack_compute_flavor_v2.flavor_medium.id
            "size": 20
            "ip": "172.16.0.5"
            "secgroup": "game"
            "network": "management"
            "user_data": file("../files/cloud-init-ubuntu.yaml")
        }
        //the logging mgmt host
        "logging": {
            "image": data.openstack_images_image_v2.image_ubuntu_20_cloud.id
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 20
            "ip": "172.16.0.69"
            "secgroup": "logging"
            "network": "management"
            "user_data": file("../files/cloud-init-ubuntu.yaml")
        }
        "scoring": {
            "image": data.openstack_images_image_v2.image_ubuntu_20_cloud.id
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 30
            "ip": "172.24.0.1"
            "secgroup": "scorestack"
            "network": "alternate"
            "user_data": templatefile("../files/cloud-init-management-dynamic-dns.yaml", var.scoring_ddclient_vars)
        }
        "beat": {
            "image": data.openstack_images_image_v2.image_ubuntu_20_cloud.id
            "flavor": data.openstack_compute_flavor_v2.flavor_medium.id
            "size": 20
            "ip": "172.24.0.2"
            "secgroup": "beat"
            "network": "alternate"
            "user_data": templatefile("../files/cloud-init-management-dynamic-dns.yaml", var.beat_ddclient_vars)
        }
        "ctf": {
            "image": data.openstack_images_image_v2.image_ubuntu_20_cloud.id
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 20
            "ip": "172.24.0.3"
            "secgroup": "ctf"
            "network": "alternate"
            //"user_data": file("../files/cloud-init-ubuntu.yaml")
            "user_data": templatefile("../files/cloud-init-management-dynamic-dns.yaml", var.ctf_ddclient_vars)
        }
        "ctfd": {
            "image": data.openstack_images_image_v2.image_ubuntu_20_cloud.id
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 20
            "ip": "172.24.0.4"
            "secgroup": "ctf"
            "network": "alternate"
            "user_data": file("../files/cloud-init-ubuntu.yaml")
            //"user_data": templatefile("../templates/cloud-init-management-dynamic-dns.yaml", var.ctf_ddclient_vars)
        }
        "store": {
            "image": data.openstack_images_image_v2.image_ubuntu_20_cloud.id
            "flavor": data.openstack_compute_flavor_v2.flavor_medium.id
            "size": 20
            "ip": "172.24.0.5"
            "secgroup": "store"
            "network": "alternate"
            //"user_data": file("../files/cloud-init-ubuntu.yaml")
            "user_data": templatefile("../files/cloud-init-management-dynamic-dns.yaml", var.store_ddclient_vars)
        }
        # phone net
        "phone": {
            "image": data.openstack_images_image_v2.image_ubuntu_20_cloud.id
            "flavor": data.openstack_compute_flavor_v2.flavor_medium.id
            "size": 20
            "ip": "172.26.0.1"
            "secgroup": "phone" //update later
            "network": "phone"
            "user_data": file("../files/cloud-init-ubuntu.yaml")
            //"user_data": file("../files/cloud-init-management.yaml")
        }
    }
}