// Project Dependent Variables:
// ----------------------------
locals {
    management_hosts = 20 # the number of hosts in the management networks
    team_lan_hosts = 9 # the number of hosts in the team lan
    team_cloud_hosts = 7 # the number of hosts in the team cloud
    team_router_extra_ports = 2 # extra ports for the router - idk why
    metadata_items_per_host = 4 # stack metadata items
    num_volumes = 8 # numbers of volumes per instance
    num_snapshots = 8 # numbers of snapshots per instance
}



// Build the competition project
resource "openstack_identity_project_v3" "management_project" {
    description = "Parent project for overarching competition"
    name = "${var.competition_name} Management"
}

resource "openstack_networking_quota_v2" "management_networking_quota" {
    project_id = openstack_identity_project_v3.management_project.id
    floatingip = 10
    network = 8 # RIT_WAN, Switching Plane, Management, Alternate, VPN, KotH
    subnet = 8  # RIT_WAN, Switching Plane, Management, Alternate, VPN, KotH
    port = 100
    router = 2  # Management, Alternate
    security_group = 15
    security_group_rule = 100
    subnetpool = 3
}

resource "openstack_compute_quotaset_v2" "management_compute_quota" {
    project_id = openstack_identity_project_v3.management_project.id
    ram = 250 * 1024
    cores = 46
    instances = local.management_hosts
    metadata_items = local.management_hosts * local.metadata_items_per_host
}

resource "openstack_blockstorage_quotaset_v3" "management_blockstorage_quota" {
    project_id = openstack_identity_project_v3.management_project.id
    volumes   = 8 * 11 * 2  # 8 volumes per 11 instances doubled
    snapshots = 8 * 11      # 8 volumes per 11 instances
    gigabytes = 1000        # Blaze it
    per_volume_gigabytes = 100
}

