# Add competition_managementgroup as data references
data "openstack_identity_group_v3" "competition_management_group"{
    name = "competition-management"
}

# Add blackteam group as data reference
data "openstack_identity_group_v3" "blackteam_group"{
    name = "blackteam"
}

data "openstack_identity_role_v3" "admin_role" {
    name = "admin"
}

data "openstack_identity_role_v3" "member_role" {
    name = "member"
}

data "openstack_identity_role_v3" "viewer_role" {
    name = "reader"
}


# define local references for the groups as a set - users in the group inherit the role 
locals { 
    group_roles = {
        (data.openstack_identity_group_v3.competition_management_group.id): data.openstack_identity_role_v3.admin_role.id
        (data.openstack_identity_group_v3.blackteam_group.id): data.openstack_identity_role_v3.member_role.id
    }
}

// Add project management group to cloud project as admins
resource "openstack_identity_role_assignment_v3" "admin_group_cloud_assignment" {
    for_each = local.group_roles
    group_id = each.key
    role_id = each.value
    project_id = openstack_identity_project_v3.cloud_project.id
}

#loop through team projects, add all users with appropriate permissions
resource "openstack_identity_role_assignment_v3" "admin_group_team_assignment" {
    count = var.num_teams
    group_id = data.openstack_identity_group_v3.competition_management_group.id
    role_id = data.openstack_identity_role_v3.admin_role.id
    project_id = openstack_identity_project_v3.team_project[count.index].id
}

resource "openstack_identity_role_assignment_v3" "member_group_team_assignment" {
    count = var.num_teams
    group_id = data.openstack_identity_group_v3.blackteam_group.id
    role_id = data.openstack_identity_role_v3.member_role.id
    project_id = openstack_identity_project_v3.team_project[count.index].id
}

// Add each team user to their team project
resource "openstack_identity_role_assignment_v3" "team_user_viewer_assignment" {
    count = var.num_teams
    user_id = openstack_identity_user_v3.team_user[count.index].id
    role_id = data.openstack_identity_role_v3.viewer_role.id
    project_id = openstack_identity_project_v3.team_project[count.index].id
}