// Project Dependent Variables:
// ----------------------------
locals {
    team_lan_hosts = 8 # the number of hosts in the team lan
    team_cloud_hosts = 7 # the number of hosts in the team cloud
    team_auxilia_hosts = 2 # the number of the hosts in the team auxilia for KoTH
    team_router_extra_ports = 10 # extra ports for the router - idk why
    metadata_items_per_host = 4 # stack metadata items
    num_volumes = 8 # numbers of volumes per instance
    num_snapshots = 8 # numbers of snapshots per instance
}

// Build Cloud Project
// The Cloud Project will host all of the teams cloud networks and infrastructures
resource "openstack_identity_project_v3" "cloud_project" {
    description = "Project for cloud networks"
    name = "${var.competition_name} Cloud"
}

// Networking Quota block define quotas for the networking stack for the cloud project
resource "openstack_networking_quota_v2" "cloud_networking_quota" {
    project_id = openstack_identity_project_v3.cloud_project.id
    floatingip = 0 # no public ips 
    network = var.num_teams
    port = var.num_teams * (local.team_cloud_hosts + 2)  # each team uses a port for each instance and network
    router = 0 # no router in the cloud
    security_group = 50 # five security groups for the cloud
    security_group_rule = 50 # twenty security groups applied in the cloud
    subnet = var.num_teams
    subnetpool = var.num_teams
}

// Compute Quota block define quotas for the cloud resources for the cloud project
resource "openstack_compute_quotaset_v2" "cloud_compute_quota" {
    project_id = openstack_identity_project_v3.cloud_project.id
    ram = var.num_teams * (28 + 1) * 1024   # Extra GB per team because openstack counts weird
    cores = var.num_teams * 16 # 14 needed, 2 for pad
    instances = var.num_teams * local.team_cloud_hosts # thats the number of instances
    metadata_items = var.num_teams * local.team_cloud_hosts * local.metadata_items_per_host
}

// Blockstorage Quota block define quotas for the storage resources for the cloud project
resource "openstack_blockstorage_quotaset_v3" "cloud_blockstorage_quota" {
    project_id = openstack_identity_project_v3.cloud_project.id
    volumes = var.num_teams * 8 * local.team_cloud_hosts * 2 # 8 volumes per cloud host
    snapshots = var.num_teams * 8 * local.team_cloud_hosts # 8 snapshos per cloud host
    gigabytes = var.num_teams * 150 * 2 # 140 need, 10 pad
    per_volume_gigabytes = 60 * 2 # idk
}

// Build Each Team Project
/* Each team gets their own team project. This will provide them with graphical interfaces to access their 
* lan hosts. The team does not get graphical access to the cloud project in order to make those hosts remote 
* access only. 
*/
resource "openstack_identity_project_v3" "team_project" {
    description = "Project for individual teams"
    count = var.num_teams
    name = format("%s Team %02d", var.competition_name, count.index + 1)
}

// Networking Quota block define quotas for the networking stack for the team projects
resource "openstack_networking_quota_v2" "team_networking_quota" {
    count = var.num_teams
    project_id = openstack_identity_project_v3.team_project[count.index].id
    floatingip = 0  # no public ips
    network = 2     # Team x LAN + 
    subnet = 2      # Team x LAN Subnet
    subnetpool = 2  # 1 subnet
    port = local.team_router_extra_ports + local.team_lan_hosts + local.team_auxilia_hosts # switching plane and network
    router = 0      # no openstack router
    security_group = 50 # two security group rules
    security_group_rule = 50 # six applications of the sec rules
}

// Compute Quota block define quotas for the cloud resources for the team projects
resource "openstack_compute_quotaset_v2" "team_compute_quota" {
    count = var.num_teams
    project_id = openstack_identity_project_v3.team_project[count.index].id
    ram = (85 + 1) * 1024   # Extra GB because openstack counts weird
    cores = 40 # 28 total cores + 8 pad 
    instances = local.team_lan_hosts + local.team_auxilia_hosts
    injected_files = 1 # uhhh what
    injected_file_path_bytes = 32 # uhhh what
    injected_file_content_bytes = 200000 # uhhh what
    metadata_items = local.team_lan_hosts * local.metadata_items_per_host
}

// Blockstorage Quota block define quotas for the storage resources for the team projects
resource "openstack_blockstorage_quotaset_v3" "team_blockstorage_quota" {
    count = var.num_teams
    project_id = openstack_identity_project_v3.team_project[count.index].id
    volumes = local.num_volumes * local.team_lan_hosts * 2 # 8 volumes per host * 2
    snapshots = local.num_snapshots * local.team_lan_hosts # 8 snapshots per host
    gigabytes = 320 * 2 # 295 required, + 35 pad
    per_volume_gigabytes = 60 
}
