provider "openstack" {
    user_name = var.user_name
    password = var.password
    auth_url = var.auth_url
    tenant_name = var.tenant_name
}

/* Image Data 
* In this section, specifiy out the names of the images. The data field will be used later in the terraform. 
* The name field should be the same name as the images created by packer. 
*/

// pfSense Router
data "openstack_images_image_v2" "image_pfsense"{
    name = "pfSense"
}

// win 11 client
data "openstack_images_image_v2" "image_win_11"{
    name = "NEW_ISTS_2022_Windows_11"
}

// win 2019 server
data "openstack_images_image_v2" "image_win_serv_19"{
    name = "NEW_ISTS_2022_Windows_Server_2019"
}


// win 2019 server
data "openstack_images_image_v2" "image_win_serv_19_irsec"{
    name = "IRSEC_2021_Win_19"
}


// ubuntu 20.04 desktop
data "openstack_images_image_v2" "image_linux_ubuntu_20"{
    name = "ISTS_2022_ubuntu_2004_desktop"
}


// ubuntu 18.04 desktop
data "openstack_images_image_v2" "image_linux_ubuntu_18"{
    name = "ISTS_2022_ubuntu_1804_desktop"
}

// blackarch desktop
data "openstack_images_image_v2" "image_linux_blackarch"{
    name = "ISTS_2022_blackarch_desktop"
}

// centOS cloud
data "openstack_images_image_v2" "image_linux_centos"{
    name = "ISTS_2022_centos_8_cloud"
}

// Debian 
data "openstack_images_image_v2" "image_linux_debian"{
    name = "ISTS_2022_debian_11"
}

// Fedora Cloud
data "openstack_images_image_v2" "image_linux_fedora_cloud"{
    name = "ISTS_2022_fedora_35_cloud"
}

// Fedora Deskotp
data "openstack_images_image_v2" "image_linux_fedora_desktop"{
    name = "ISTS_2022_fedora_35_desktop"
}

// Kali
data "openstack_images_image_v2" "image_linux_kali"{
    name = "ISTS_2022_kali_2021.1"
}

/* Flavor Data
*/
data "openstack_compute_flavor_v2" "flavor_medium" {
    name = "Medium general"
}

data "openstack_compute_flavor_v2" "flavor_medium_mem"{
    name = "Medium memory"
}

data "openstack_compute_flavor_v2" "flavor_large" {
    name = "Large general"
}

data "openstack_compute_flavor_v2" "flavor_large_mem" {
    name = "Large memory"
}

data "openstack_compute_flavor_v2" "flavor_extreme_mem" {
    name = "Extreme memory"
}

// Build the team's lan
module "team_lan" {
    source ="./team_lan"
    provider_info = {
        user_name: var.user_name
        password: var.password
        auth_url: var.auth_url
        tenant_name: format("${var.competition_name} Team %02d", var.team_num)
    }
    competition_name = var.competition_name
    competition_domain = var.competition_domain
    team_num = var.team_num
    inherited_tags = var.inherited_tags

    /* Router is special, so it gets its own stuff 
    EXAMPLE:
    router = {
        "hostname": "fudo"
        "image": data.openstack_images_image_v2.image_palo_alto.id
        "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
        "ip_MGMT": "10.${var.team_num}.1.7"
        "ip_LAN": "10.${var.team_num}.1.254"
        "ip_WAN": "10.100.0.${100 + var.team_num}"
    } */

    router = {
        "hostname": "pfsense"
        "image": data.openstack_images_image_v2.image_pfsense.id
        "flavor": data.openstack_compute_flavor_v2.flavor_medium_mem.id
        "ip_WAN": "10.100.0.${100 + var.team_num}"
        "ip_LAN": "10.${var.team_num}.1.254"
    }

    /* Host details: hostnames, images, flavors, sizes, ips 
    */
    hosts = {
        "arboretum": {
            "image": data.openstack_images_image_v2.image_win_serv_19_irsec.id //update with windows serv name
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 45
            "ip": "10.${var.team_num}.1.1"
        }
        "sternwood": {
            "image": data.openstack_images_image_v2.image_win_serv_19.id //update with windows serv name
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 45
            "ip": "10.${var.team_num}.1.2"
        }
        "limest": {
            "image": data.openstack_images_image_v2.image_win_serv_19.id //update with windows serv name
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 45
            "ip": "10.${var.team_num}.1.3"
        }
        "laurast": {
            "image": data.openstack_images_image_v2.image_win_11.id //update with windows 11 name
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 45
            "ip": "10.${var.team_num}.1.4"
        }
        "kingsbylake": {
            "image": data.openstack_images_image_v2.image_linux_blackarch.id //update with arch image
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 60
            "ip": "10.${var.team_num}.1.6"
            "user_data": file("../files/cloud-init-blackarch.yaml") // update w/ new cloud init
        }
        "oldwarren": { //weird OS
            "image": data.openstack_images_image_v2.image_linux_ubuntu_20.id // update with linux image
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 35
            "ip": "10.${var.team_num}.1.7"
            "user_data": file("../files/cloud-init-ubuntu.yaml") // update w/ new cloud init
        }
        "windowct": {
            "image": data.openstack_images_image_v2.image_linux_ubuntu_20.id // update with linux image
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 45
            "ip": "10.${var.team_num}.1.69"
            "user_data": file("../files/cloud-init-ubuntu.yaml") // update w/ new cloud init
        }
    }
}

// Build the team's cloud
module "team_cloud" {
    source ="./team_cloud"
    provider_info = {
        user_name: var.user_name
        password: var.password
        auth_url: var.auth_url
        tenant_name: "${var.competition_name} Cloud"
    }
    competition_name = var.competition_name
    competition_domain = var.competition_domain
    team_num = var.team_num
    inherited_tags = var.inherited_tags

    /* 
    In this section, specify all of the hosts for the cloud network, just as you did for the lan
    Make sure that each host has the following host details: hostnames, images, flavors, sizes, ips, userdata(optional)
    Reference the above examples as needed
    */
    hosts = {
        "reardon": {
            "image": data.openstack_images_image_v2.image_linux_fedora_cloud.id
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 25
            "ip": "172.16.${var.team_num}.1"
        }
        "cutout": {
            "image": data.openstack_images_image_v2.image_linux_centos.id
            "flavor": data.openstack_compute_flavor_v2.flavor_medium.id
            "size": 25
            "ip": "172.16.${var.team_num}.11"
        }
        "livedrop": {
            "image": data.openstack_images_image_v2.image_linux_debian.id
            "flavor": data.openstack_compute_flavor_v2.flavor_medium.id
            "size": 25
            "ip": "172.16.${var.team_num}.12"
            "user_data": file("../files/cloud-init-ubuntu.yaml")
        }
        "honeypot": {
            "image": data.openstack_images_image_v2.image_win_serv_19.id
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 40
            "ip": "172.16.${var.team_num}.13"
        }
        "watcher": {
            "image": data.openstack_images_image_v2.image_linux_ubuntu_18.id
            "flavor": data.openstack_compute_flavor_v2.flavor_medium.id
            "size": 25
            "ip": "172.16.${var.team_num}.20"
        }
    }
}

// Build the team's logging host
module "team_auxilia" {
    source ="./team_auxilia"
    provider_info = {
        user_name: var.user_name
        password: var.password
        auth_url: var.auth_url
        tenant_name: format("${var.competition_name} Team %02d", var.team_num)
    }
    competition_name = var.competition_name
    competition_domain = var.competition_domain
    team_num = var.team_num
    inherited_tags = var.inherited_tags

    /* 
    In this section, specify all of the hosts for the logging network, just as you did for the lan
    Make sure that each host has the following host details: hostnames, images, flavors, sizes, ips, userdata(optional)
    Reference the above examples as needed
    */
    hosts = {
        "winKoTH": {
            "image": data.openstack_images_image_v2.image_win_11.id // update with windows image
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 40
            "ip": "192.168.${var.team_num}.11"
        }
        "linKoTH": {
            "image": data.openstack_images_image_v2.image_linux_kali.id
            "flavor": data.openstack_compute_flavor_v2.flavor_large_mem.id
            "size": 40
            "ip": "192.168.${var.team_num}.16"
            //"user_data": file("../files/cloud-init-ubuntu.yaml")
        }    
    }
}