data "openstack_networking_router_v2" "core_router" {
    /*
    The Core Router sits on the management network and 
    connects almost everything together
    */
    name = "${var.competition_name} Core Router"
}

data "openstack_networking_secgroup_v2" "auxilia_secgroup" {
    name = format("%s Team %02d Auxilia Secgroup", var.competition_name, var.team_num)
}

// Auxilia Network
resource "openstack_networking_network_v2" "auxilia_network" {
    name = format("Team %02d Auxilia", var.team_num)
}

// the auxilia subnet
resource "openstack_networking_subnet_v2" "auxilia_subnet" {
    name = format("Team %02d Auxilia Subnet", var.team_num)
    network_id = openstack_networking_network_v2.auxilia_network.id
    cidr = "192.168.${var.team_num}.0/24"
    gateway_ip = "192.168.${var.team_num}.254"
    ip_version = 4
    allocation_pool {
        start = "192.168.${var.team_num}.200"
        end = "192.168.${var.team_num}.253"
    }
    dns_nameservers = [
        "172.16.0.1",
        "172.16.0.2",
    ]
}

resource "openstack_networking_port_v2" "auxilia_router_port" {
    name = "auxilia Router Port"
    network_id = openstack_networking_network_v2.auxilia_network.id
    fixed_ip {
        subnet_id = openstack_networking_subnet_v2.auxilia_subnet.id
        ip_address = "192.168.${var.team_num}.254"
    }
}

resource "openstack_networking_router_interface_v2" "auxilia_interface" {
    router_id = data.openstack_networking_router_v2.core_router.id
    port_id = openstack_networking_port_v2.auxilia_router_port.id
}
