resource "openstack_compute_instance_v2" "team_cloud_instance" {
    depends_on = [ openstack_networking_subnet_v2.team_cloud_subnet ]
    for_each = var.hosts
    name = format("%s.team%02d.%s", each.key, var.team_num, var.competition_domain)
    flavor_id = each.value.flavor
    tags = setunion(var.inherited_tags,  // comp name
                    [format("project-${var.competition_name}-team-${var.team_num}")], // project name
                    [format("team-${var.team_num}-Cloud")], // Network Location
                    [format("team-${var.team_num}-${each.key}")] //hostname
                    )
    security_groups = [
        "default",
        data.openstack_networking_secgroup_v2.cloud_secgroup.id
    ]
    block_device {
        uuid = each.value.image
        volume_size = each.value.size
        boot_index = 0
        delete_on_termination = true
        source_type = "image"
        destination_type = "volume"
    }
    network {
        uuid = openstack_networking_network_v2.team_cloud.id
        fixed_ip_v4 = each.value.ip
    }
    user_data = lookup(each.value, "user_data", null)
}
