data "openstack_networking_router_v2" "core_router" {
    name = "${var.competition_name} Core Router"
}

data "openstack_networking_secgroup_v2" "cloud_secgroup" {
    name = "${var.competition_name} Cloud Secgroup"
}

// Team Cloud Network
resource "openstack_networking_network_v2" "team_cloud" {
    name = format("Team %02d Cloud", var.team_num)
}

resource "openstack_networking_subnet_v2" "team_cloud_subnet" {
    name = format("Team %02d Cloud Subnet", var.team_num)
    network_id = openstack_networking_network_v2.team_cloud.id
    cidr = "172.16.${var.team_num}.0/24"
    gateway_ip = "172.16.${var.team_num}.254"
    ip_version = 4
    allocation_pool {
        start = "172.16.${var.team_num}.200"
        end = "172.16.${var.team_num}.253"
    }
    dns_nameservers = [
        "172.16.0.1",
        "172.16.0.2"
    ]
}

resource "openstack_networking_port_v2" "team_core_router_port" {
    name = format("Team %02d Cloud Router Port", var.team_num)
    network_id = openstack_networking_network_v2.team_cloud.id
    fixed_ip {
        subnet_id = openstack_networking_subnet_v2.team_cloud_subnet.id
        ip_address = "172.16.${var.team_num}.254"
    }
}

resource "openstack_networking_router_interface_v2" "core_router_cloud_interface" {
    router_id = data.openstack_networking_router_v2.core_router.id
    port_id = openstack_networking_port_v2.team_core_router_port.id
}
