resource "openstack_compute_instance_v2" "team_lan_instance" {
    /*
    In this instances block, we take everything that we specified in the team/main.tf file, 
    and turn them into the attribuates on the stack

    We could probably assign tags 
    */
    depends_on = [ openstack_networking_subnet_v2.team_lan_subnet ]
    for_each = var.hosts //we define a list like structure
    name = format("%s.team%02d.%s", each.key, var.team_num, var.competition_domain) // assign the host name
    flavor_id = each.value.flavor // assign the flavor
    tags = setunion(var.inherited_tags,  // comp name
                    [format("project-${var.competition_name}-team-${var.team_num}")], // project name
                    [format("team-${var.team_num}-LAN")], // Network Location
                    [format("team-${var.team_num}-${each.key}")] //hostname
                    )
    security_groups = [ // assign security groups
        "default",
        data.openstack_networking_secgroup_v2.team_secgroup.id
    ]
    block_device { // assign image attributes 
        uuid = each.value.image // the actual image
        volume_size = each.value.size // the disk size
        boot_index = 0
        delete_on_termination = true
        source_type = "image"
        destination_type = "volume"
    }
    network {
        uuid = openstack_networking_network_v2.team_lan.id // assign a uuid
        fixed_ip_v4 = each.value.ip // assign the ip address
    }
    user_data = lookup(each.value, "user_data", null) // assign user data, if it exists
}

// Router
resource "openstack_compute_instance_v2" "team_router" {
    /*
    This compute instance block specifies the router instance parameters
    */
    depends_on = [ openstack_networking_subnet_v2.team_lan_subnet ]
    // Name in the format Hostname Team Number Domain Name
    name = format("%s.team%02d.%s", var.router.hostname , var.team_num, var.competition_domain)
    flavor_id = var.router.flavor //router flavor
    tags = setunion(var.inherited_tags,  // comp name
                    [format("project-${var.competition_name}-team-${var.team_num}")], // project name
                    [format("team-${var.team_num}-LAN")], // Network Location
                    [format("team-${var.team_num}-${var.router.hostname}")] //hostname
                    )
    security_groups = [ // router security groups
        "default",
        data.openstack_networking_secgroup_v2.team_secgroup.id
    ]
    block_device {
        // router images attributes
        uuid = var.router.image
        volume_size = 60
        boot_index = 0
        delete_on_termination = true
        source_type = "image"
        destination_type = "volume"
    }
    network {
        // WAN IP 
        port = openstack_networking_port_v2.switching_plane_router_port.id
    }
    network {
        // LAN IP
        port = openstack_networking_port_v2.team_lan_router_port.id
    }
}
